@@ -1,14 +1,20 @@
-"""jc - JSON Convert Proc file output parser
+r"""jc - JSON Convert Proc file output parser
 
 This parser automatically identifies the Proc file and calls the
 corresponding parser to perform the parsing.
 
 Magic syntax for converting `/proc` files is also supported by running
 `jc /proc/<path to file>`. Any `jc` options must be specified before the
-`/proc` path.
+`/proc` path. The magic syntax supports "slurping" multiple files as input.
+When multiple files are selected (e.g. `jc /proc/*/stat`) all of the output
+will be wrapped inside an array. Also, a `_file` field will be included in
+the output which helps correlate the input and output. The `--meta-out`
+option can also be used to list the `/proc` input files for correlation with
+the output list.
 
-specific Proc file parsers can also be called directly, if desired and have
-a naming convention of `proc-<name>` (cli) or `proc_<name>` (module).
+Specific Proc file parsers can also be called directly, if desired, and have
+a naming convention of `proc-<name>` (cli) or `proc_<name>` (module). To see
+a list of Proc file parsers, use `jc -hh` or `jc -a`.
 
 Usage (cli):
 
@@ -45,7 +51,7 @@ Schemas can also be found online at:
 
 For example:
 
-    https://kellyjonbrazil.github.io/jc/docs/parsers/proc_meminfo
+https://kellyjonbrazil.github.io/jc/docs/parsers/proc_meminfo
 
 Examples:
 
@@ -112,20 +118,20 @@ Examples:
     ]
 """
 import re
-import importlib
-from typing import List, Dict
+from typing import List, Dict, Union
 import jc.utils
+from jc.lib import get_parser
 from jc.exceptions import ParseError
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.1'
+    version = '1.4'
     description = '`/proc/` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
-    tags = ['file']
+    tags = ['file', 'slurpable']
 
 
 __version__ = info.version
@@ -135,7 +141,7 @@ def parse(
     data: str,
     raw: bool = False,
     quiet: bool = False
-) -> List[Dict]:
+) -> Union[List[Dict], Dict]:
     """
     Main text parsing function
 
@@ -147,13 +153,14 @@ def parse(
 
     Returns:
 
-        List of Dictionaries. Raw or processed structured data.
+        Dictionary or List of Dictionaries. Raw or processed structured data.
     """
     jc.utils.input_type_check(data)
 
     if jc.utils.has_data(data):
         # signatures
         buddyinfo_p = re.compile(r'^Node \d+, zone\s+\w+\s+(?:\d+\s+){11}\n')
+        cmdline_p = re.compile(r'^BOOT_IMAGE=')
         consoles_p = re.compile(r'^\w+\s+[\-WUR]{3} \([ECBpba ]+\)\s+\d+:\d+\n')
         cpuinfo_p = re.compile(r'^processor\t+: \d+.*bogomips\t+: \d+.\d\d\n', re.DOTALL)
         crypto_p = re.compile(r'^name\s+:.*\ndriver\s+:.*\nmodule\s+:.*\n')
@@ -212,6 +219,7 @@ def parse(
 
         procmap = {
             buddyinfo_p: 'proc_buddyinfo',
+            cmdline_p: 'proc_cmdline',
             consoles_p: 'proc_consoles',
             cpuinfo_p: 'proc_cpuinfo',
             crypto_p: 'proc_crypto',
@@ -272,7 +280,7 @@ def parse(
         for reg_pattern, parse_mod in procmap.items():
             if reg_pattern.search(data):
                 try:
-                    procparser = importlib.import_module('jc.parsers.' + parse_mod)
+                    procparser = get_parser(parse_mod)
                     return procparser.parse(data, quiet=quiet, raw=raw)
                 except ModuleNotFoundError:
                     raise ParseError('Proc file type not yet implemented.')
